# CHANGELOG

<!-- version list -->

## v1.4.0 (2026-01-25)

### Features

- Context Lifecycle, Coaching Model & Workflow Decomposition
  ([#4](https://github.com/luutuankiet/gsd-lite/pull/4),
  [`bc13fe6`](https://github.com/luutuankiet/gsd-lite/commit/bc13fe6549571d9757779c56058f7731341a740a))


## v1.3.4 (2026-01-24)

### Bug Fixes

- Folder naming bump to gsd-lite
  ([`948ef68`](https://github.com/luutuankiet/gsd-lite/commit/948ef68093f4c3bcc6f8a16e7c6d2841a2f467f7))


## v1.3.3 (2026-01-24)

### Bug Fixes

- Add relpath to not confuse agent
  ([`d538479`](https://github.com/luutuankiet/gsd-lite/commit/d53847954c7e4fd78f9ef6cbf9c3ca8edbf1cebc))


## v1.3.2 (2026-01-24)

### Bug Fixes

- Also scaffold templates dir into state if not exist
  ([`1b267d3`](https://github.com/luutuankiet/gsd-lite/commit/1b267d3bbbbf7d1f226d5ea4f45f0b8458bf0fba))


## v1.3.1 (2026-01-24)

### Bug Fixes

- Broken markdown in protocol
  ([`898c460`](https://github.com/luutuankiet/gsd-lite/commit/898c460be8fc0c91ddc04d43e1ac13de2b5c4d04))


## v1.3.0 (2026-01-23)

### Bug Fixes

- Use native markdown instead
  ([`64bde07`](https://github.com/luutuankiet/gsd-lite/commit/64bde0749e79e9065a3ed6c986fd7bd995ce1aa0))

### Features

- More detailed logging for WORK.md protocol
  ([`2598249`](https://github.com/luutuankiet/gsd-lite/commit/259824963d744b5a7e259a1aa2cd5a6058d8436e))


## v1.2.0 (2026-01-23)

### Features

- Prompt agent to extract vision and collaboratively think with user
  ([`95a942b`](https://github.com/luutuankiet/gsd-lite/commit/95a942b1d72f85ea35aa55e2efebf76814e365d9))


## v1.1.1 (2026-01-23)

### Bug Fixes

- No more ascii art line break
  ([`fe94da4`](https://github.com/luutuankiet/gsd-lite/commit/fe94da4eb3aa7b16c9c2e5c1c59dd0986c8cb1b9))


## v1.1.0 (2026-01-23)

### Features

- Stabilize versioning pipeline
  ([`03b60ae`](https://github.com/luutuankiet/gsd-lite/commit/03b60aea43e157af8f14249c09d3db84eab911af))


## v1.0.0 (2026-01-23)

- Initial Release
